Documentation
¶
Index ¶
- Variables
- func AppFlags(writer io.Writer) func(*flagset)
- func BuildInfoJson(writer io.Writer)
- func BuildInfoYaml(writer io.Writer)
- func ConfigFlags(writer io.Writer, structs ...any) func(*flagset)
- func FlagConfigGenEnv(structs ...any) func(string) error
- func FlagConfigInfoEnv(writer io.Writer, structs ...any) func(string) error
- func Flags(writer io.Writer, args []string, flagsets ...func(*flagset))
- type App
- type AppOption
- type BuildInfo
- type Closer
- type Pool
- type PoolTask
- type Service
Constants ¶
This section is empty.
Variables ¶
var ( BuildDate string = unset GitBranch string = unset GitCommit string = unset GoVersion string = unset GitTag string = unset )
Build flags variables
var (
ErrSuccessExit = errors.New("success and exit with code 0")
)
Functions ¶
func BuildInfoJson ¶ added in v0.0.4
func BuildInfoYaml ¶ added in v0.0.4
func ConfigFlags ¶ added in v0.0.2
func FlagConfigGenEnv ¶ added in v0.0.4
func FlagConfigInfoEnv ¶ added in v0.0.4
Types ¶
type App ¶
func (*App) AddServices ¶
type BuildInfo ¶ added in v0.0.4
type BuildInfo struct {
BuildDate string `json:"build_date,omitempty" yaml:"build_date,omitempty"`
GitBranch string `json:"git_branch,omitempty" yaml:"git_branch,omitempty"`
GitCommit string `json:"git_commit,omitempty" yaml:"git_commit,omitempty"`
GoVersion string `json:"go_version,omitempty" yaml:"go_version,omitempty"`
GitTag string `json:"git_tag,omitempty" yaml:"git_tag,omitempty"`
}
Directories
¶
| Path | Synopsis |
|---|---|
|
pkg
|
|
|
bot
package bot contains
|
package bot contains |
|
colors
The colors package provides text highlighting functionality through the Higlighter struct, which can highlight numbers and keywords in strings using configurable color codes.
|
The colors package provides text highlighting functionality through the Higlighter struct, which can highlight numbers and keywords in strings using configurable color codes. |
Click to show internal directories.
Click to hide internal directories.