Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigFlags ¶ added in v0.0.2
func ConfigFlags(structs ...any)
Types ¶
type App ¶
func (*App) AddServices ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
pkg
|
|
|
colors
The colors package provides text highlighting functionality through the Higlighter struct, which can highlight numbers and keywords in strings using configurable color codes.
|
The colors package provides text highlighting functionality through the Higlighter struct, which can highlight numbers and keywords in strings using configurable color codes. |
Click to show internal directories.
Click to hide internal directories.